from pyluks.luksctl_api.luksctl_api_master import app as master_app
from pyluks.luksctl_api.luksctl_api_wn import app as wn_app

if __name__ == '__main__':
    master_app.run(host='0.0.0.0:5000', debug=True)


# Import dependencies
from flask import Flask, jsonify, request
import os
import logging
from configparser import ConfigParser

# Import internal dependencies
from .luksctl_run import wn



################################################################################
# APP CONFIGS

app = Flask(__name__)

# Load configs
luks_cryptdev_file = '/etc/luks/luks-cryptdev.ini'
if os.path.exists(luks_cryptdev_file):
    
    # Read cryptdev ini file
    config = ConfigParser()
    config.read(luks_cryptdev_file)
    api_config = config['luksctl_api']

    # Set variables from cryptdev ini file
    nfs_mountpoint_list = api_config['NFS_MOUNTPOINT_LIST'] if 'NFS_MOUNTPOINT_LIST' in api_config else None
    
    # Define node instance
    wn_node = wn(nfs_mountpoint_list)

else:
    raise FileNotFoundError('Cryptdev ini file missing.')


@app.route('/luksctl_api_wn/v1.0/status', methods=['GET'])
def get_status():
    return wn_node.get_status()


@app.route('/luksctl_api_wn/v1.0/nfs-mount', methods=['POST'])
def nfs_mount():
    return wn.nfs_mount()


# Import dependencies
import subprocess
import logging

#__________________________________
# Function to run bash commands
def run_command(cmd, LOGFILE=None):
    """
    Run subprocess call redirecting stdout, stderr and the command exit code.
    """
    proc = subprocess.Popen(args=cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    communicateRes = proc.communicate()
    stdout, stderr = [x.decode('utf-8') for x in communicateRes]
    status = proc.wait()

    # Functionality to replicate cmd >> "$LOGFILE" 2>&1
    if LOGFILE != None:
        with open(LOGFILE, 'a+') as log:
            log.write(f'{stdout}\n{stderr}')
    
    return stdout, stderr, status


#__________________________________
# Create logging facility
def create_logger(logfile, name):

    # Define logging format
    formatter = logging.Formatter('%(levelname)s %(asctime)s %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
    
    # Define logging handler
    handler = logging.FileHandler(logfile, mode='a+')  
    handler.setFormatter(formatter)

    # Create logger
    logger = logging.getLogger(name)
    logger.setLevel(0)
    logger.addHandler(handler)

    return logger



# Import dependencies
from flask import Flask, jsonify, request
import os
import logging
from configparser import ConfigParser

# Import internal dependencies
from .luksctl_run import master, api_logger



################################################################################
# APP CONFIGS

app = Flask(__name__)

# Load configs
luks_cryptdev_file = '/etc/luks/luks-cryptdev.ini'
if os.path.exists(luks_cryptdev_file):
    
    # Read cryptdev ini file
    config = ConfigParser()
    config.read(luks_cryptdev_file)
    api_config = config['luksctl_api']

    # Set variables from cryptdev ini file
    infrastructure_config = api_config['INFRASTRUCTURE_CONFIGURATION']
    virtualization_type = api_config['VIRTUALIZATION_TYPE'] if 'VIRTUALIZATION_TYPE' in api_config else None
    node_list = api_config['WN_IPS'] if 'WN_IPS' in api_config else None
    
    # Define node instance
    master_node = master(infrastructure_config, virtualization_type, node_list)

else:
    raise FileNotFoundError('Cryptdev ini file missing.')




################################################################################
# FUNCTIONS

#______________________________________
@app.route('/luksctl_api/v1.0/status', methods=['GET'])
def get_status():
    
    return master.get_status()


#______________________________________
@app.route('/luksctl_api/v1.0/open', methods=['POST'])
def luksopen():

    if not request.json or \
       not 'vault_url' in request.json or \
       not 'vault_token' in request.json or \
       not 'secret_root' in request.json or \
       not 'secret_path' in request.json or \
       not 'secret_key' in request.json:
       abort(400)

    if master_node.get_node_list() != None:
        api_logger.debug(master_node.get_node_list())

    return master_node.open(request.json['vault_url'],
                            request.json['vault_token'],
                            request.json['secret_root'],
                            request.json['secret_path'],
                            request.json['secret_key'])